migrate

package
v1.12.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 15, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package migrate handles database schema migration for the example2 application.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DropAllTables

func DropAllTables() error

DropAllTables drops all the tables. Use with caution!

func StartMigration

func StartMigration(configure gconfig.Configuration) error

StartMigration automatically migrates all the tables.

  • Only create tables with missing columns and missing indexes.
  • Will not change/delete any existing columns and their types.

Types

This section is empty.

Jump to